@@ -73,7 +73,7 @@ void k9ExecCopy::copyDVD() {
 
     long fs=k9Tools::getFreeSpace(outputDir);
     if ((fs <  config.getPrefSize()) && (fs !=-1)) {
-        if (k9Dialogs::warningContinueCancel ( i18n("Insufficient disk space on %1\n%2 mb expected.").arg(outputDir,config.getPrefSize()),i18n("DVD Copy"))==cancel)
+        if (k9Dialogs::warningContinueCancel ( i18n("Insufficient disk space on %1\n%2 MB expected.").arg(outputDir).arg(config.getPrefSize()),i18n("DVD Copy"))==cancel)
             return;
     }
 
