@@ -11,27 +11,31 @@
 //
 #include "k9mp4enc.h"
 #include "k9mp4dlg.h"
-#include "k9config.h"
 #include <qapplication.h>
-#include <klocale.h>
 #include <qstringlist.h>
 #include <qdir.h>
-#include <kfiledialog.h>
-#include <kmessagebox.h>
+
 #include <qstringlist.h>
-#include <KTemporaryFile>
-#include <kstandarddirs.h>
 #include "k9tools.h"
 #include "k9audiocodecs.h"
 #include "k9videocodecs.h"
 #include "k9convertaudio.h"
 #include <QByteArray>
 #include "k9dialogs.h"
-#include <KShell>
 #include <QMutex>
 #include <math.h>
 #include "k9ifo2.h"
 #include "k9cell.h"
+#include "k9vamps.h"
+#include "k9log.h"
+
+#ifndef BACKLITE
+#include <kfiledialog.h>
+#include <kmessagebox.h>
+#include <KShell>
+
+#endif
+
 #define BASE_CONV_AUDIO 0
 #define BASE_CONV_VIDEO 10
 
@@ -120,6 +124,7 @@ bool k9MP4Enc::check() {
     sCodecA=audioCodecs->getEncoder(m_audioCodec);
 
     if (m_extractAudio && sCodecA !="ffmpeg") {
+        k9log::add(i18n("Audio extraction can only be done with ffmpeg"),k9logLevel::ERROR);
         k9Dialogs::error(i18n("Audio extraction can only be done with ffmpeg"),i18n("Encoding error"));
         return false;
     }
@@ -128,13 +133,15 @@ bool k9MP4Enc::check() {
     sCodecV=videoCodecs->getEncoder (m_codec);
 
     if (m_extractMkv && sCodecV!="ffmpeg") {
+        k9log::add(i18n("Matroska encoding can only be done with ffmpeg"),k9logLevel::ERROR);
         k9Dialogs::error(i18n("Matroska encoding can only be done with ffmpeg"),i18n("Encoding error"));
         return false;
     }
 
     if (!m_extractAudio) {
         if ( ! k9Tools::checkProgram(sCodecV) ) {
-            k9Dialogs::error (i18n("Unable to run %1",sCodecV) , i18n("Encoding error"));
+            k9log::add(i18n("Unable to run %1").arg(sCodecV),k9logLevel::ERROR);
+            k9Dialogs::error (i18n("Unable to run %1").arg(sCodecV) , i18n("Encoding error"));
             m_error = TRUE;
             return false;
         }
@@ -144,7 +151,8 @@ bool k9MP4Enc::check() {
 
     if ((sCodecA!=sCodecV) || m_extractAudio) {
         if ( ! k9Tools::checkProgram(sCodecA) ) {
-            k9Dialogs::error (i18n("Unable to run %1",sCodecA) , i18n("Encoding error"));
+            k9log::add(i18n("Unable to run %1").arg(sCodecV),k9logLevel::ERROR);
+            k9Dialogs::error (i18n("Unable to run %1").arg(sCodecA) , i18n("Encoding error"));
             m_error = TRUE;
             return false;
         }
@@ -155,6 +163,13 @@ bool k9MP4Enc::check() {
 }
 
 void k9MP4Enc::execute(k9DVDTitle *_title) {
+    if (m_mpeg2)
+        k9log::add(i18n("Starting extraction of %1, chapters %2").arg(_title->getname()).arg(getChapterList( _title)),k9logLevel::INFO);
+    else
+        k9log::add(i18n("Starting encoding of %1, chapters %2").arg(_title->getname()).arg(getChapterList( _title)),k9logLevel::INFO);
+    k9log::add(i18n("source : %1").arg(m_device),k9logLevel::INFO);
+    k9log::add(i18n("destination : %1").arg(m_filename),k9logLevel::INFO);
+    k9log::add(i18n("disk cache : %1").arg( m_usecache ? i18n("activated"):i18n("disabled")),k9logLevel::INFO);
     m_currentChapter=0;
     m_error=false;
     m_outputFile=NULL;
@@ -173,16 +188,19 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
     m_remain="--:--:--";
 
     m_totalSize=_title->getChaptersSize(true);
-
+    k9log::add(i18n("size : %1 MB").arg(m_totalSize/512),k9logLevel::INFO);
+    if (!m_mpeg2) {
+        k9log::add(i18n("audio bitrate : %1").arg(m_audioBitrate),k9logLevel::INFO);
+        if (!m_extractAudio) {
+            if (m_videoBitrate !="")
+                k9log::add(i18n("user defined video bitrate : %1").arg(m_videoBitrate),k9logLevel::INFO);
+            else
+                k9log::add(i18n("calculated video bitrate : %1").arg(getBitRate(_title)),k9logLevel::INFO);
+            }
+    }
     QString injectName;
-    KTemporaryFile injectFile;
-    injectFile.setPrefix(KStandardDirs::locateLocal("tmp", "k9copy/k9v"));
-    injectFile.open();
-    injectName=injectFile.fileName();
-
-    injectFile.setAutoRemove(true);
-    injectFile.close();
-
+    k9Config config;
+    injectName=config.getPrefOutput()+"/k9v"+k9Tools::randomFileName()+".tmp";
 
     int maxPass=0;
     int pass=0;
@@ -197,16 +215,16 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
             maxPass=2;
             pass=1;
         }
-        KTemporaryFile passLogFile;
         QString passLogFileName;
-        passLogFile.setPrefix(KStandardDirs::locateLocal("tmp", "k9copy/k9v"));
-        passLogFile.setAutoRemove(true);
-        passLogFile.open();
-        passLogFileName=passLogFile.fileName();
-        passLogFile.close();
+        k9Config config;
+        passLogFileName=QDir::cleanPath(config.getPrefOutput()+"/k9v"+k9Tools::randomFileName() +".temp");
         m_passLogFile=passLogFileName;
 
         do {
+            if (!m_mpeg2)
+                k9log::add(i18n("starting pass %1 of %2").arg(pass==0 ? 1:pass).arg(maxPass==0 ? 1 : maxPass),k9logLevel::INFO);
+            m_totalBytes=0;
+            m_vamps=NULL;
             m_player=new k9play(this);
 
             uint32_t nbSectors= m_totalSize / m_parts   ;
@@ -282,12 +300,11 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
             if (! m_videoBitrate.isEmpty()) {
                 if (!m_mpeg2 && !m_extractAudio && !m_extractMkv) {
                     m_progress->setsize(QString::number(m_parts) +" * "+m_size +i18n("MB"));
-                    m_player->setendSector(QString::number(endSector));
                 } else
                     m_progress->setsize(m_size +i18n("MB") );
             } else
                 m_progress->setsize("");
-
+            m_player->setendSector(QString::number(endSector));
             QStringList cmd;
 
             m_player->setinject(injectName);
@@ -330,10 +347,11 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
                     m_player->setsubpictureFilter(streams.join(","));
                 }
             }
+
             m_player->setuseCache(m_usecache);
 
+
             if (m_mpeg2) {
-                m_offset+=m_totalBytes;
                 m_progress->setbitrate("--");
                 double size;
 
@@ -388,7 +406,7 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
 
             foreach (k9ConvertAudio *c,m_converters) {
                 if (c) {
-                    c->end();
+                    c->end(true);
                 }
             }
             foreach(k9Subtitle2Pgm *s,m_subtitles) {
@@ -406,7 +424,9 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
                 pass++;
             delete m_player;
             m_player = NULL;
-        } while (pass<=maxPass && !m_error && m_2pass);
+        } while (pass<=maxPass && !m_error && m_2pass && !m_canceled);
+        if (!m_canceled)
+            m_offset+=m_totalBytes+ (m_vamps !=NULL ? m_vamps->getSkippedBytes():0);
 
     }
     if (m_mpeg2 && m_outputFile) {
@@ -417,7 +437,7 @@ void k9MP4Enc::execute(k9DVDTitle *_title) {
         c->end();
         delete c;
     }
-
+    QFile::remove(injectName);
     if (!m_msgError.isEmpty())
         k9Dialogs::error (m_msgError, i18n("Encoding error"),m_ErrorDetail);
 
@@ -470,7 +490,7 @@ void k9MP4Enc::buildAudioCmd(k9DVDTitle *title) {
 
             QString sAOption=replaceParams(audioCodecs->getOptions(m_audioCodec)).trimmed();
 
-            m_progress->setTitleLabel(i18n("Encoding %1",sCodec));
+            m_progress->setTitleLabel(i18n("Encoding %1").arg(sCodec));
             QString path,ext=audioCodecs->getExtension(m_audioCodec) ;
             if (!ext.startsWith("."))
                 ext="."+ext;
@@ -481,6 +501,8 @@ void k9MP4Enc::buildAudioCmd(k9DVDTitle *title) {
 
 
             cmd  << m_ffmpegPath << "-i" << "/dev/stdin" <<sAOption.split(" ") <<  KShell::quoteArg(path) ;
+
+            k9log::add(i18n("starting thread : %1").arg(cmd.join(" ")),k9logLevel::INFO);
             k9ConvertAudio *converter=new k9ConvertAudio("",cmd);
             m_converters[BASE_CONV_AUDIO+i]=converter;
             m_convertersToDelete << converter;
@@ -532,9 +554,9 @@ void k9MP4Enc::buildFFMpegCmd(int pass,k9DVDTitle *title,QStringList &cmd) {
     cmd << sVOption.split(" ");
 
     if (pass >0)
-        m_progress->setTitleLabel(i18n("Encoding %1",sCodec)+" - "+i18n("pass %1",pass));
+        m_progress->setTitleLabel(i18n("Encoding %1").arg(sCodec)+" - "+i18n("pass %1").arg(pass));
     else
-        m_progress->setTitleLabel(i18n("Encoding %1",sCodec));
+        m_progress->setTitleLabel(i18n("Encoding %1").arg(sCodec));
 
     if (m_fourcc !="")
         cmd << "-vtag" << m_fourcc;
@@ -599,9 +621,9 @@ void k9MP4Enc::buildFFMpegCmd(int pass,k9DVDTitle *title,QStringList &cmd) {
     //synchronize audio
     cmd << "-async" << "1" ;
     cmd << "-y"  << KShell::quoteArg(path);
-
     cmd << slNewAudio;
 //    if (m_extractMkv) {
+    k9log::add(i18n("starting thread : %1").arg(cmd.join(" ")),k9logLevel::INFO);
     k9ConvertAudio *converter=new k9ConvertAudio("",cmd);
     //converter->setDebug(true);
     m_converters[BASE_CONV_VIDEO]=converter;
@@ -651,9 +673,9 @@ void k9MP4Enc::buildMEncoderCmd(int pass,int part,k9DVDTitle *title,const QStrin
 
 
     if (pass >0)
-        m_progress->setTitleLabel(i18n("Encoding %1",sCodec)+" - "+i18n("pass %1",pass));
+        m_progress->setTitleLabel(i18n("Encoding %1").arg(sCodec)+" - "+i18n("pass %1").arg(pass));
     else
-        m_progress->setTitleLabel(i18n("Encoding %1",sCodec));
+        m_progress->setTitleLabel(i18n("Encoding %1").arg(sCodec));
 
     if (m_fourcc !="")
         cmd << "-ffourcc" << m_fourcc;
@@ -708,6 +730,7 @@ void k9MP4Enc::buildMEncoderCmd(int pass,int part,k9DVDTitle *title,const QStrin
         //      cmd << "-of" << "lavf";
         //      cmd << "-lavfopts" << "i_certify_that_my_video_stream_does_not_use_b_frames";
     }
+    k9log::add(i18n("starting thread : %1").arg(cmd.join(" ")),k9logLevel::INFO);
     k9ConvertAudio *converter=new k9ConvertAudio("",cmd);
     converter->setDebug(false);
     m_converters[BASE_CONV_VIDEO]=converter;
@@ -715,6 +738,7 @@ void k9MP4Enc::buildMEncoderCmd(int pass,int part,k9DVDTitle *title,const QStrin
 }
 
 void k9MP4Enc::slotCancel() {
+    k9log::add(i18n("cancel requested"),k9logLevel::WARNING);
     m_canceled=true;
     timer->stop();
     m_player->abort();
@@ -792,14 +816,14 @@ int k9MP4Enc::getBitRate(k9DVDTitle *_title) {
 
 void k9MP4Enc::timerDone() {
     if (m_player) {
-        uint32_t totalBytes,totalSize;
-        m_player->getPosition(&totalBytes,&totalSize);
         if (m_converters[BASE_CONV_VIDEO])
             m_progress->setfps(m_converters[BASE_CONV_VIDEO]->getFps());
-        if (totalSize !=0)
-            m_percent=(float)(m_offset+totalBytes) / (float)m_totalSize;
-        m_totalBytes=totalBytes;
+        if (m_totalSize !=0) {
 
+            m_percent=(float)(m_offset+m_totalBytes+( m_vamps!=NULL? m_vamps->getSkippedBytes():0)) / (float)m_totalSize;
+//            qDebug() <<"offset" << m_offset << " total readen:" <<  m_totalBytes << " total skipped : " << (m_vamps!=NULL? m_vamps->getSkippedBytes():0) << " total title :" << m_totalSize << "percent" << m_percent;
+
+        }
         QTime time2(0,0);
         time2=time2.addMSecs(time->elapsed());
         if (m_percent>0) {
@@ -821,7 +845,8 @@ bool k9MP4Enc::isCanceled() {
 
 
 void k9MP4Enc::getOutput(eStreamType streamType,int streamNumber,uchar *buffer,uint32_t size) {
-    if (m_error)
+
+    if (isCanceled())
         return;
     if ((streamType==NAV) && !m_mpeg2) {
         pci_t	 pci_pack;
@@ -855,8 +880,9 @@ void k9MP4Enc::getOutput(eStreamType streamType,int streamNumber,uchar *buffer,u
         else {
             m_player->setAborted(true);
             m_error=true;
-            m_msgError=i18n("An error occured while encoding the %1 stream",i18n("audio"));
+            m_msgError=i18n("An error occured while encoding the %1 stream").arg(i18n("audio"));
             m_ErrorDetail=c->getOutput();
+            k9log::add(m_msgError,k9logLevel::ERROR);
         }
     }
 
@@ -879,8 +905,9 @@ void k9MP4Enc::getOutput(eStreamType streamType,int streamNumber,uchar *buffer,u
             else {
                 m_player->setAborted(true);
                 m_error=true;
-                m_msgError=i18n("An error occured while encoding the %1 stream",i18n("video"));
+                m_msgError=i18n("An error occured while encoding the %1 stream").arg(i18n("video"));
                 m_ErrorDetail=c->getOutput();
+                k9log::add(m_msgError,k9logLevel::ERROR);
             }
         }
     }
@@ -894,6 +921,7 @@ void k9MP4Enc::getOutput(eStreamType streamType,int streamNumber,uchar *buffer,u
 
 
 void k9MP4Enc::getOutput(uchar *buffer,uint32_t size) {
+    m_totalBytes+= size/2048  ;
     if (m_mpeg2 ) {
         //waiting for free space in the fifo buffer (readen by mencoder process)
         m_fifo.addData(buffer,size);
@@ -912,7 +940,7 @@ void k9MP4Enc::Flush() {
     uchar buffer[40960];
     int size;
     do {
-        while (m_fifo.count()>0) {
+        while (m_fifo.count()>0 ) {
             size=m_fifo.readData(buffer,2048);
 
             if (m_mpeg2 && m_splitChapters && k9Cell::isNavPack(buffer)) {
@@ -950,12 +978,14 @@ void k9MP4Enc::Flush() {
     } while (!m_player->terminated() && !m_canceled && m_mpeg2);
 
     m_player->wait();
+
 }
 
 
 
 k9MP4Enc::~k9MP4Enc() {
-    m_progress->close();
+    delete m_progress;
+
 }
 
 
