@@ -12,9 +12,11 @@
 #ifndef K9DRAWIMAGE_H
 #define K9DRAWIMAGE_H
 
-#include <qwidget.h>
-#include <qpixmap.h>
-
+#include <QWidget>
+#include <QPixmap>
+#include <QMutex>
+#include <QTimer>
+#include <QImage>
 /**
 	@author Jean-Michel PETIT <k9copy@free.fr>
 */
@@ -28,9 +30,14 @@ public:
     ~k9DrawImage();
 private:
     QPixmap m_pixmap;
-
+    QImage m_image;
+    QMutex m_mutex;
+    bool m_repaint;
+    QTimer m_timer;
 protected:
     void paintEvent ( QPaintEvent *);
+protected slots:
+    void timerDone();
 };
 
 #endif
