@@ -13,15 +13,13 @@
 
 #include "k9progress.h"
 #include <QProgressBar>
-#include <qlabel.h>
-#include <qapplication.h>
-#include <qeventloop.h>
-#include <qimage.h>
-#include <qpainter.h>
-#include <kstandarddirs.h>
-#include <qmovie.h>
-#include <qlayout.h>
-
+#include <QLabel>
+#include <QApplication>
+#include <QEventLoop>
+#include <QImage>
+#include <QPainter>
+#include <QMovie>
+#include <QLayout>
 
 
 k9Progress::k9Progress(QWidget* parent)
@@ -32,9 +30,25 @@ k9Progress::k9Progress(QWidget* parent)
     m_wimage=new k9DrawImage(Ui_Progress.image);
     QGridLayout *l=new QGridLayout(Ui_Progress.image);
     l->addWidget(m_wimage,0,0);
+#ifndef BACKLITE
     Ui_Progress.bCancel->setGuiItem(KStandardGuiItem::Stop);
 
+    QString aright=KGlobal::dirs()->findResource( "data", QString("k9copy/aright.png"));
+    QString adown=KGlobal::dirs()->findResource( "data", QString("k9copy/adown.png"));
+    Ui_Progress.gbOutput->setStyleSheet("*::indicator:unchecked {image:url("+aright+"); } *::indicator:checked {image:url("+adown+"); } ");
+#else
+    Ui_Progress.bCancel->setText(i18n("Stop"));
+    Ui_Progress.bCancel->setIcon(style()->standardIcon(QStyle::SP_DialogCancelButton));
+    Ui_Progress.gbOutput->setStyleSheet("*::indicator:unchecked {image:url(:/icons/aright); } *::indicator:checked {image:url(:/icons/adown); } ");
+#endif
+    m_movie=NULL;
 
+
+}
+
+void k9Progress::showEvent ( QShowEvent *  ) {
+    k9Config config;
+    Ui_Progress.gbOutput->setChecked(config.getPrefShowOutput());
 }
 
 
@@ -109,13 +123,41 @@ void k9Progress::setImage(const QImage &_image) {
 void k9Progress::setMovie(QString _fileName) {
     m_wimage->hide();
     Ui_Progress.image->setPalette(this->palette());
-    QMovie *mv=new QMovie(_fileName);
- //   mv.setBackgroundColor(this->paletteBackgroundColor());
-    Ui_Progress.image->setMovie(mv);
-    mv->start();
+    m_movie=new QMovie(_fileName);
+    m_movie->start();
+    Ui_Progress.image->setMovie(m_movie);
+
 }
 
 
 bool k9Progress::getCanceled() const {
     return m_canceled;
 }
+
+
+void k9Progress::gbOutputToggled(bool state) {
+    k9Config config;
+   if (!state) {
+        m_outputSize=Ui_Progress.image->height();
+        if (m_movie)
+            Ui_Progress.image->clear();
+        Ui_Progress.image->setMinimumSize(0,0);
+        this->resize(this->width(),this->height()-m_outputSize);
+        m_outputSize-=Ui_Progress.image->height();
+        this->setMaximumHeight(this->height());
+
+    } else {
+        this->setMaximumHeight(32768);
+        this->resize(this->width(),this->height()+m_outputSize);
+        if (m_movie)
+          Ui_Progress.image->setMovie(m_movie);
+    }
+
+    config.setPrefShowOutput(state);
+    config.save();
+    Ui_Progress.image->setVisible(state);
+}
+
+void k9Progress::closeEvent ( QCloseEvent *  ) {
+
+}
