@@ -16,7 +16,7 @@
 #include <qthread.h>
 #include <qobject.h>
 #include <qdatetime.h>
-#include <KTemporaryFile>
+#include <QTemporaryFile>
 #include "k9fifo.h"
 #include <qimage.h>
 
@@ -51,7 +51,7 @@ private:
     bool m_stop;
     QTime m_timer;
     uint m_cpt;
-    KTemporaryFile *m_tempFile;
+    QTemporaryFile *m_tempFile;
     uchar *m_buffer;
     uint32_t m_size;
     QMutex m_mutex;
