@@ -19,10 +19,11 @@
 	@author Jean-Michel PETIT <k9copy@free.fr>
 */
 
+
 class k9Tools{
 private:
-    k9Tools() {};
-    ~k9Tools(){};
+    k9Tools() {}
+    ~k9Tools(){}
 public: 
    static bool checkProgram(QString _progName,bool _msg=false);
    static void clearOutput(QString name);
@@ -31,7 +32,17 @@ public:
    static long getFreeSpace(const QString &_path);
    static bool runAsRoot(const QString &_command,const QString &_description);
    static void addTemporaryDir(const QString &dir);
-
+   static const QString getTempPath() ;
+   static const QString randomFileName();
+   static QString findExe(const QString _program);
 };
 
+#ifdef BACKLITE
+QIcon SmallIcon(const QString &name);
+QIcon getStdIcon(const QString &name);
+class KShell {
+public:
+    static QString quoteArg( const QString &arg );
+};
+#endif
 #endif
