@@ -6,30 +6,30 @@
 //
 // Author: Jean-Michel PETIT <k9copy@free.fr>, (C) 2005
 //
-// Copyright: See COPYING file that comes with this distribution
+// Copyright: See COPYING file that comes nth this distribution
 //
 //
 #include "k9importfiles.h"
 #include "k9settings.h"
-#include "k9config.h"
-#include <kdeversion.h>
-#include <kstatusbar.h>
-#include <kstdaccel.h>
+
 #include <kaction.h>
-#include <KStandardAction>
 #include <qframe.h>
-#include <kedittoolbar.h>
-#include <klibloader.h>
 #include "k9tools.h"
 #include <QDockWidget>
 #include "images.h"
-#include <KShortcutsDialog>
 #include "dvdread.h"
 #include <QMenu>
+#include <QCloseEvent>
+#ifndef BACKLITE
+#include <kdeversion.h>
+#include <KStandardAction>
+#include <kstatusbar.h>
+#include <kstdaccel.h>
 #include <KActionCollection>
 #include <KMenuBar>
-#include <QCloseEvent>
-
+#include <KShortcutsDialog>
+#include <kedittoolbar.h>
+#endif
 
 #include "k9import.h"
 #include "k9menuedit.h"
@@ -37,7 +37,7 @@
 #include "k9newtitle.h"
 #include "k9menu.h"
 #include "k9dialogs.h"
-
+#include "kdialog.h"
 k9ImportFiles::k9ImportFiles(k9Copy *_parent)
         : KXmlGuiWindow(_parent,0 ) {
    // accept dnd
@@ -54,16 +54,23 @@ k9ImportFiles::k9ImportFiles(k9Copy *_parent)
     setupActions();
 
     // and a status bar
+    m_drives=new k9CdDrives(this);
+    createWindows();
+#ifndef BACKLITE
     statusBar()->show();
     statusBar()->insertFixedItem("",sbFactor);
     statusBar()->setItemFixed(sbFactor,100);
     statusBar()->insertItem("",sbMessage,1);
     statusBar()->setItemAlignment(sbMessage,Qt::AlignLeft | Qt::AlignVCenter);
-    m_drives=new k9CdDrives();
-    createWindows();
-   // backupAction->setChecked(true);
     setupGUI();
+#endif
 
+   // backupAction->setChecked(true);
+#ifdef BACKLITE
+    k9Config config;
+    restoreGeometry(config.getPrefGeometry("import"));
+#endif
+    changeCaption(i18n("DVD Author"));
 }
 
 
@@ -103,7 +110,7 @@ void k9ImportFiles::createWindows() {
     doc=new QDockWidget(this);//
     firstDock=doc;
     doc->setFeatures(QDockWidget::DockWidgetMovable | QDockWidget::DockWidgetFloatable |QDockWidget::DockWidgetClosable);
-    m_menuEdit=new k9MenuEdit(this,0,m_k9Import->getNewDVD()->getRootMenu()->getCanvas());
+    m_menuEdit=new k9MenuEdit(this,0,m_k9Import->getNewDVD()->getRootMenu()->getScene());
     doc->setWidget(m_menuEdit);
     doc->setObjectName("menuEdit");
     doc->setWindowTitle(i18n("Edit menu"));
@@ -115,7 +122,9 @@ void k9ImportFiles::createWindows() {
     m_k9Import->init();
 
     setActions(true);
+#ifndef BACKLITE
     setAutoSaveSettings();
+#endif
 }
 
 void k9ImportFiles::removeToolWindows() {
@@ -145,24 +154,57 @@ bool k9ImportFiles::queryClose   (    ) {
 }
 
 void k9ImportFiles::setupActions() {
+    m_actions["create"] = new KAction(KIcon("author"),i18n("Create DVD"),this);
+    backupAction = new KAction(KIcon("dvdcopy"),i18n("DVD Backup"),this );
+    m_actions["backup"]=backupAction;
 
+#ifdef BACKLITE
+    QMenu *fileMenu=menuBar()->addMenu(i18n("&File"));
+    QToolBar *toolbar=addToolBar("Actions");
+#if QT_VERSION >= 0x040600
+    toolbar->setToolButtonStyle(Qt::ToolButtonFollowStyle);
+#else
+    toolbar->setToolButtonStyle( Qt::ToolButtonTextUnderIcon);
+#endif
+    QMenu *actionMenu=menuBar()->addMenu(i18n("A&ctions"));
+    QMenu *configureMenu=menuBar()->addMenu(i18n("&Options"));
+
+    m_actions["quit"]=new KAction(style()->standardIcon(QStyle::SP_DialogCloseButton),i18n("&Quit"),this);
+    connect(m_actions["quit"],SIGNAL(triggered(bool)),SLOT(quit()));
+
+    fileMenu->addAction(m_actions["quit"]);
+
+
+    m_actions["preferences"]=new KAction(SmallIcon("configure"),i18n("Settings"),this);
+    connect(m_actions["preferences"],SIGNAL(triggered(bool)),SLOT(preferences()));
+    configureMenu->addAction(m_actions["preferences"]);
+
+    fileMenu->addSeparator();
+    actionMenu->addAction(m_actions["create"]);
+    actionMenu->addAction(backupAction);
+    toolbar->addAction(m_actions["create"]);
+    toolbar->addSeparator();
+    toolbar->addAction(m_actions["preferences"]);
+    toolbar->addSeparator();
+    toolbar->addAction(m_actions["quit"]);
+
+#else
     m_actions["quit"]=KStandardAction::quit(this, SLOT(quit()),(QObject*) actionCollection());
     m_actions["preferences"]=KStandardAction::preferences(this,SLOT(preferences()),(QObject*)actionCollection());
     KStandardAction::keyBindings(this, SLOT(optionsConfigureKeys()), (QObject*)actionCollection());
-   KStandardAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), (QObject*)actionCollection());
+    KStandardAction::configureToolbars(this, SLOT(optionsConfigureToolbars()), (QObject*)actionCollection());
 
 
     setStandardToolBarMenuEnabled(TRUE);
     createStandardStatusBarAction();
 
-    m_actions["create"] = new KAction(KIcon("author"),i18n("Create DVD"),this);
     actionCollection()->addAction("Create",m_actions["create"]);
-    connect(m_actions["create"], SIGNAL(triggered(bool)), SLOT(ActionCreate()));
 
-    backupAction = new KAction(i18n("DVD Backup"),this );
-    actionCollection()->addAction("backup",backupAction);   
+    actionCollection()->addAction("backup",backupAction);
+#endif
+
+    connect(m_actions["create"], SIGNAL(triggered(bool)), SLOT(ActionCreate()));
     connect(backupAction, SIGNAL(triggered(bool)), SLOT(ActionBackup()));
-    m_actions["backup"]=backupAction;
 }
 
 void k9ImportFiles::setActions( bool enabled) {
@@ -177,27 +219,31 @@ void k9ImportFiles::setActions( bool enabled) {
 }
 
 void k9ImportFiles::optionsConfigureKeys() {
+#ifndef BACKLITE
     KShortcutsDialog::configure(actionCollection());
+#endif
 }
 
 void k9ImportFiles::optionsConfigureToolbars() {
-    // use the standard toolbar editor
-//    saveMainWindowSettings(KGlobal::config(), autoSaveGroup());
+#ifndef BACKLITE
     KEditToolBar dlg(factory());
     connect(&dlg,SIGNAL(newToolbarConfig()),this,SLOT(newToolbarConfig()));
     dlg.exec();
+#endif
 }
 
 void k9ImportFiles::newToolbarConfig() {
     // this slot is called when user clicks "Ok" or "Apply" in the toolbar editor.
     // recreate our GUI, and re-apply the settings (e.g. "text under icons", etc.)
+#ifndef BACKLITE
     createGUI(0);
+#endif
 
 //    applyMainWindowSettings(KGlobal::config(), autoSaveGroup());
 }
 
 void k9ImportFiles::preferences() {
-    k9settings settings(this,i18n("Settings"));
+    k9Settings settings(k9Dialogs::getMainWidget(),i18n("Settings"));
     settings.exec();
 }
 
@@ -218,18 +264,20 @@ void k9ImportFiles::ActionBackup() {
 
 void k9ImportFiles::changeStatusbar(const QString& text,int id) {
     // display the text on the statusbar
+#ifndef BACKLITE
     statusBar()->changeItem(text,id);
+#endif
 }
 
 void k9ImportFiles::changeCaption(const QString& text) {
     // display the text on the caption
-    setCaption(text);
+    setWindowTitle(KDialog::makeStandardCaption(text));
 }
 
 
 void k9ImportFiles::quit() {
     close( );
-    kapp->quit();
+    qApp->quit();
 }
 
 
@@ -237,7 +285,11 @@ void k9ImportFiles::closeEvent( QCloseEvent* ce ) {
     k9Config config;
     if (config.getPrefDelTmpFiles())
         k9Tools::clearOutput(config.getPrefOutput()+"/dvd");
-    ce->accept();
+#ifdef BACKLITE
+    config.setPrefGeometry(saveGeometry(),"import");
+    config.save();
+#endif
+    ce->accept();    
     m_parent->show();
 }
 
