@@ -29,31 +29,29 @@
 #include "k9mp4enc.h"
 #include "k9settings.h"
 #include "k9langselect.h"
-#include "k9config.h"
 #include "k9updatefactor.h"
 #include "k9titleencopt.h"
 #include "k9tools.h"
-#include <kcombobox.h>
 #include <qapplication.h>
 #include <kurlrequester.h>
-#include <kurl.h>
 #include <qdir.h>
-#include <kstandarddirs.h>
 #include <qstatusbar.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
 #include <qpixmap.h>
 #include <qspinbox.h>
 #include <qpainter.h>
+#ifndef BACKLITE
 #include <kdirselectdialog.h>
-
-#include <kdeversion.h>
-#include <qbitmap.h>
-#include "images.h"
+#include <kcombobox.h>
+#include <kstandarddirs.h>
 #include <KDiskFreeSpace>
 #include <kmountpoint.h>
 #include <kiconloader.h>
-#include "k9process.h"
+#include <kdeversion.h>
+#endif
+#include <qbitmap.h>
+#include "images.h"
 #include "k9execcopy.h"
 #include <QMenu>
 #include "k9dialogs.h"
@@ -117,6 +115,7 @@ void k9Main::clearItems() {
 
 k9Main::k9Main ( QWidget* parent, const char* , k9CdDrives *_drives )
         : QWidget ( parent ) {
+    m_ready=false;
     Ui_MainDlg.setupUi ( this );
     listView1=Ui_MainDlg.listView1;
     connect ( Ui_MainDlg.cbOutputDev,SIGNAL ( currentIndexChanged ( int ) ),this,SLOT ( cbOutputDevActivated ( int ) ) );
@@ -143,30 +142,30 @@ k9Main::k9Main ( QWidget* parent, const char* , k9CdDrives *_drives )
 //  items.setAutoDelete(true);
 //  listView1->setDefaultRenameAction(QListView::Accept);
     //    KStandardDirs kd;
-    m_prefOutput=KStandardDirs::locateLocal ( "tmp","k9copy/",true ); //kd.findResource("tmp","");
+    m_prefOutput=k9Tools::getTempPath();
     connect ( drives,SIGNAL ( deviceAdded ( k9CdDrive* ) ),this,SLOT ( deviceAdded ( k9CdDrive* ) ) );
     connect ( drives,SIGNAL ( deviceRemoved ( k9CdDrive* ) ),this,SLOT ( deviceRemoved ( k9CdDrive* ) ) );
 
     readSettings();
-//    Ui_MainDlg.binputOpen->setIcon ( SmallIcon ( "document-open" ) );
-//    Ui_MainDlg.binputOpenDir->setIcon ( SmallIcon ( "folder-open" ) );
+
     emit SelectionChanged ( NULL,true );
     m_update=new k9UpdateFactor ( this,"" );
     connect ( m_update,SIGNAL ( updateFactor_internal() ),this,SLOT ( updateFactor_internal() ) );
     cbOutputChanged(Ui_MainDlg.cbOutput->currentIndex());
     cbInputChanged(Ui_MainDlg.cbInput->currentIndex());
     
-    
     Ui_MainDlg.cbInput->setItemIcon(iDVD,SmallIcon("media-optical"));
     Ui_MainDlg.cbInput->setItemIcon(iISO,SmallIcon("document-open"));
     Ui_MainDlg.cbInput->setItemIcon(iFolder,SmallIcon("document-open-folder"));
-    
+
     Ui_MainDlg.cbOutput->setItemIcon(oDVD,SmallIcon("media-optical-recordable"));
     Ui_MainDlg.cbOutput->setItemIcon(oISO,SmallIcon("document-open"));
     Ui_MainDlg.cbOutput->setItemIcon(oMP4,SmallIcon("video-mp4"));
     Ui_MainDlg.cbOutput->setItemIcon(oMPEG2,SmallIcon("video-mpeg"));
     Ui_MainDlg.cbOutput->setItemIcon(oAudio,SmallIcon("audio-basic"));
     Ui_MainDlg.cbOutput->setItemIcon(oFolder,SmallIcon("document-open-folder"));
+
+    m_ready=true;
 }
 
 
@@ -393,12 +392,12 @@ void k9Main::Copy() {
 	  if ( Ui_MainDlg.cbOutput->currentIndex() ==oFolder) {
 	      execCopy.setOutput ( k9ExecCopy::oFolder );
 	      // changed from home to preferred output directory (bkp)
-	      path= Ui_MainDlg.urOutput->url().pathOrUrl();
+              path= Ui_MainDlg.urOutput->url().path();
 	      if ( path=="" )
 		  return;
 	  } else if ( Ui_MainDlg.cbOutput->currentIndex() ==oISO ) {
 	      // changed QDir::homePath() to m_prefOutput (bkp)
-	      path= Ui_MainDlg.urOutput->url().pathOrUrl();
+              path= Ui_MainDlg.urOutput->url().path();
 	      if ( path =="" )
 		  return;
 	      execCopy.setOutput ( k9ExecCopy::oISO );
@@ -453,6 +452,7 @@ void k9Main::Open() {
 
     listView1->disconnect ( SIGNAL ( itemChanged ( QTreeWidgetItem*,int ) ) );
     listView1->disconnect ( SIGNAL ( currentItemChanged ( QTreeWidgetItem * , QTreeWidgetItem * ) ) );
+
     disconnect ( m_langSelect->listView(),0,0,0 );
 
 
@@ -464,7 +464,7 @@ void k9Main::Open() {
     tsItems.clear();
     chItems.clear();
 
-    QString sDevice=Ui_MainDlg.cbInput->currentIndex()==iDVD ? getDevice ( Ui_MainDlg.cbInputDev ): Ui_MainDlg.urInput->url().pathOrUrl();
+    QString sDevice=Ui_MainDlg.cbInput->currentIndex()==iDVD ? getDevice ( Ui_MainDlg.cbInputDev ): Ui_MainDlg.urInput->url().path();
 
     QString sVolName="";
     //if no dvd label, try to get it from hal
@@ -482,10 +482,10 @@ void k9Main::Open() {
 
 #endif
     k9Config config;
-
+#ifndef BACKLITE
     if ( sDevice.startsWith ( "/dev/" ) && config.getPrefReadAhead() !=-1 )
         k9CdDrive::setReadAhead ( sDevice,config.getPrefReadAhead() );
-
+#endif
     dvd->scandvd ( sDevice,m_quickScan );
     if ( dvd->geterror() ) {
         k9Dialogs::error ( dvd->geterrMsg(), i18n ( "Open DVD" ) );
@@ -504,13 +504,14 @@ void k9Main::Open() {
     root->setFlags ( root->flags() | Qt::ItemIsEditable );
     root->obj=NULL;
     root->streamType=NONE;
+
     root->setIcon ( 0,SmallIcon ( "media-optical" ) );
 
     for ( i=0;i<dvd->gettitlesetCount();i++ ) {
         ckLvItem *tsItem = new ckLvItem ( root,this,TITLESET );
         tsItem->setExpanded ( TRUE );
         QString c;
-        c=i18n ( "Titleset %1",i+1 );
+        c=i18n ( "Titleset %1").arg(i+1 );
         tsItem->setText ( 0,c );
         QFont font=tsItem->font ( 1 );
         font.setWeight ( QFont::Bold );
@@ -522,6 +523,7 @@ void k9Main::Open() {
         tsItem->streamType=NONE;
         // tsItem->setRenameEnabled(0,false);
         tsItems.append ( tsItem );
+
         tsItem->setIcon ( 0,SmallIcon ( "folder-open" ) );
     }
 
@@ -586,11 +588,11 @@ void k9Main::addChapters ( QTreeWidgetItem *_parent,k9DVDTitle *_title ) {
     int ch=0;
     for ( int i=0;i< _title->getchapterCount();i++ ) {
         ckLvItem *it =new ckLvItem ( chapter,this,CHAPTER );
-        it->setText ( 0,i18n ( "chapter %1",++ch ) );
+        it->setText ( 0,i18n ( "chapter %1").arg(++ch ) );
         QString s;
 
         s=QString ( "%1" ).arg ( ( double ) ( _title->getChapter ( i )->getsectors() ) /512,0,'f',2 );
-        it->setText ( 1,i18n ( "%1 MB",s ) );
+        it->setText ( 1,i18n ( "%1 MB").arg(s ) );
         it->setTextAlignment ( 1,Qt::AlignRight | Qt::AlignVCenter);
         it->setTextAlignment ( 2,Qt::AlignRight | Qt::AlignVCenter);
 
@@ -604,13 +606,13 @@ void k9Main::addChapters ( QTreeWidgetItem *_parent,k9DVDTitle *_title ) {
         k9DVDTitle *title2=_title->getTitles().at ( j );
         for ( int i=0;i< title2->getchapterCount();i++ ) {
             ckLvItem *it =new ckLvItem ( chapter,this,CHAPTER );
-            it->setText ( 0,i18n ( "chapter %1",++ch ) );
+            it->setText ( 0,i18n ( "chapter %1").arg(++ch ) );
             it->streamType=CHAP;
             it->obj=title2->getChapter ( i );
             QString s;
             s=QString ( "%1" ).arg ( ( double ) ( title2->getChapter ( i )->getsectors() ) /512,0,'f',2 );
 
-            it->setText ( 1,i18n ( "%1 MB",s ) );
+            it->setText ( 1,i18n ( "%1 MB").arg(s ) );
             it->setTextAlignment ( 1,Qt::AlignRight | Qt::AlignVCenter );
             it->setTextAlignment ( 2,Qt::AlignRight | Qt::AlignVCenter );
 
@@ -641,6 +643,7 @@ void k9Main::addTitle ( k9DVDTitle *track ) {
     itemTrack->setExpanded ( false );
     itemTrack->setText ( col1,track->getname() );
     itemTrack->setFlags ( itemTrack->flags() | Qt::ItemIsEditable );
+
     itemTrack->setIcon ( col1,SmallIcon ( "title" ) );
     c.sprintf ( "%.2f ", track->gettotalsize_mb() );
 
@@ -658,10 +661,11 @@ void k9Main::addTitle ( k9DVDTitle *track ) {
     ckLvItem *video;
     video=new ckLvItem ( itemTrack,this,STREAM );
     video->streamType=VID;
+
     video->setIcon ( 0,SmallIcon ( "video" ) );
     addListItem ( track,video,VID );
     video->setExpanded ( false );
-    c=i18n ( "video %1 ",track->getformat() );
+    c=i18n ( "video %1 ").arg(track->getformat() );
     c.append ( " - " + track->getaspectRatio() );
      
     video->setText ( col1, c );
@@ -674,12 +678,14 @@ void k9Main::addTitle ( k9DVDTitle *track ) {
 
     for ( i=0;i< track->getaudioStreamCount();i++ ) {
         l_auds=track->getaudioStream ( i );
-        c=i18n ( "audio %1 ",i+1 );
+        c=i18n ( "audio %1 ").arg(i+1 );
         c.append ( l_auds->getlanguage() + " " +l_auds->getformat() +" " );
         ch.sprintf ( "%dch ",l_auds->getchannels() );
         c.append ( ch+l_auds->getfrequency() +" "+l_auds->getquantization() );
         ckLvItem * item = new ckLvItem ( itemTrack,this,STREAM );
+
         item->setIcon ( 0,SmallIcon ( "sound" ) );
+
         item->streamType=AUD;
         item->language=l_auds->getlanguage();
         addListItem ( l_auds,item,AUD );
@@ -696,9 +702,10 @@ void k9Main::addTitle ( k9DVDTitle *track ) {
     }
     for ( i=0;i< track->getsubPictureCount();i++ ) {
         l_sub=track->getsubtitle ( i );
-        c=i18n ( "subpicture %1 ",i+1 );
+        c=i18n ( "subpicture %1 ").arg(i+1 );
         c.append ( l_sub->getlanguage() );
         ckLvItem * item = new ckLvItem ( itemTrack,this,STREAM );
+
         item->setIcon ( 0,SmallIcon ( "subtitle" ) );
         item->streamType=SUB;
         item->language=l_sub->getlanguage();
@@ -743,7 +750,7 @@ void k9Main::updateSelection() {
 	}
 	bool singleAudio=(Ui_MainDlg.cbOutput->currentIndex()==oMP4) && (title->getEncOpt()->getEncoder()=="mencoder");
 	bool singleSubp=(Ui_MainDlg.cbOutput->currentIndex()==oMP4) && (title->getEncOpt()->getEncoder()=="mencoder");
-	bool noSubp=(Ui_MainDlg.cbOutput->currentIndex()==oMP4) && (title->getEncOpt()->getEncoder()=="ffmpeg") && (!Ui_MainDlg.urOutput->url().fileName().endsWith(".mkv"));
+        bool noSubp=(Ui_MainDlg.cbOutput->currentIndex()==oMP4) && (title->getEncOpt()->getEncoder()=="ffmpeg") && (!Ui_MainDlg.urOutput->url().path().endsWith(".mkv"));
 	
         switch ( litem->streamType ) {
         case SUB:
@@ -1039,6 +1046,7 @@ void k9Main::collapsed ( QTreeWidgetItem *item ) {
     if ( item->type() ==1001 ) {
         ckLvItem *ckit = ( ckLvItem* ) item;
         if ( ckit->objectType==TITLESET )
+
             ckit->setIcon ( 0,SmallIcon ( "folder" ) );
     }
     resizeColumns();
@@ -1172,7 +1180,7 @@ void k9Main::PreviewTitle() {
 void k9Main::CreateMP4() {
     k9ExecCopy execCopy;
     execCopy.setDvd ( dvd );
-    execCopy.setPath(Ui_MainDlg.urOutput->url().pathOrUrl());
+    execCopy.setPath(Ui_MainDlg.urOutput->url().path());
     execCopy.CreateMP4();
     changeStatusbar ( i18n ( "Ready" ) ,sbMessage );
 
@@ -1181,7 +1189,7 @@ void k9Main::CreateMP4() {
 void k9Main::extractAudio() {
     k9ExecCopy execCopy;
     execCopy.setDvd ( dvd );
-    execCopy.setPath(Ui_MainDlg.urOutput->url().pathOrUrl());
+    execCopy.setPath(Ui_MainDlg.urOutput->url().path());
     execCopy.extractAudio();
     changeStatusbar ( i18n ( "Ready" ) ,sbMessage );
 
@@ -1191,7 +1199,7 @@ void k9Main::extractAudio() {
 void k9Main::extractMPEG2() {
     k9ExecCopy execCopy;
     execCopy.setDvd ( dvd );
-    execCopy.setPath(Ui_MainDlg.urOutput->url().pathOrUrl());
+    execCopy.setPath(Ui_MainDlg.urOutput->url().path());
     execCopy.extractMPEG2();
     changeStatusbar ( i18n ( "Ready" ) ,sbMessage );
 
@@ -1243,16 +1251,20 @@ void k9Main::addDrive ( k9CdDrive *drive ) {
     \fn k9Main::readDrives()
  */
 void k9Main::readDrives() {
+    bool ready=m_ready;
+    m_ready=false;
     Ui_MainDlg.cbInputDev->clear();
     Ui_MainDlg.cbOutputDev->clear();
     driveList.clear();
     recorderList.clear();
     drives->scanDrives();
-
+    m_ready=ready;
 }
 
 
 void k9Main::volumeChanged ( const QString &device,const QString &volumeName ) {
+    if (!m_ready)
+        return;
     if ( device==dvd->getDevice() && dvd->getopened() && volumeName=="" )
         closeDVD();
     else if ( !dvd->getopened() && volumeName !="" && getDevice ( Ui_MainDlg.cbInputDev ) ==device && Ui_MainDlg.cbInput->currentIndex()==iDVD) {
@@ -1332,8 +1344,12 @@ void k9Main::cbOutputDevActivated ( int _index ) {
         foreach ( int speed,list ) {
             Ui_MainDlg.cbBurnSpeed->addItem ( QString::number ( ( double ) ( speed ) /1385 ) );
         }
-	Ui_MainDlg.urOutput->setMode(KFile::Directory);
-        Ui_MainDlg.urOutput->setPath(drive->device);
+#ifdef BACKLITE
+        Ui_MainDlg.urOutput->setMode(KUrlRequester::DIRECTORY);
+#else
+        Ui_MainDlg.urOutput->setMode(KFile::Directory);
+#endif
+        Ui_MainDlg.urOutput->setUrl(KUrl(drive->device));
 
     }
 }
@@ -1380,7 +1396,7 @@ void k9Main::setInput ( QString _input ) {
         }
     }
     if ( !found ) {
-        Ui_MainDlg.urInput->setPath(_input );
+        Ui_MainDlg.urInput->setUrl(KUrl(_input) );
 	Ui_MainDlg.cbInput->setCurrentIndex(iFolder);
     }
 }
@@ -1429,7 +1445,7 @@ void k9Main::updateFactor_internal() {
 	}
         else {
             changeStatusbar ( QString::number ( dbfactor,'f',2 ),sbFactor );
-	    changeStatusbar ( i18n("%1 MB",QString::number ((double)sizeSelected/512.,'f',2)),sbSelSize);
+            changeStatusbar ( i18n("%1 MB").arg(QString::number ((double)sizeSelected/512.,'f',2)),sbSelSize);
 	}
         emit SelectionChanged ( dvd,withMenus() );
         m_mutex.unlock();
@@ -1455,15 +1471,25 @@ void k9Main::cbInputChanged(int _index)
      case iISO: //Iso Image
 	Ui_MainDlg.cbInputDev->hide();
         Ui_MainDlg.urInput->show();
+#ifdef BACKLITE
+        Ui_MainDlg.urInput->setMode(KUrlRequester::OPEN);
+        Ui_MainDlg.urInput->setFilter("Iso Image (*.iso)");
+#else
         Ui_MainDlg.urInput->setMode(KFile::ExistingOnly | KFile::File);
-	Ui_MainDlg.urInput->fileDialog()->setOperationMode(KFileDialog::Opening);
+        Ui_MainDlg.urInput->fileDialog()->setOperationMode(KFileDialog::Opening);
         Ui_MainDlg.urInput->setFilter("*.iso|Iso Image (*.iso)");
+#endif
+
       break;
      case iFolder: //Folder
 	Ui_MainDlg.cbInputDev->hide();
         Ui_MainDlg.urInput->show();
-	Ui_MainDlg.urInput->setMode(KFile::ExistingOnly | KFile::Directory);
-	Ui_MainDlg.urInput->fileDialog()->setOperationMode(KFileDialog::Opening);
+#ifdef BACKLITE
+        Ui_MainDlg.urInput->setMode(KUrlRequester::DIRECTORY);
+#else
+        Ui_MainDlg.urInput->setMode(KFile::ExistingOnly | KFile::Directory);
+        Ui_MainDlg.urInput->fileDialog()->setOperationMode(KFileDialog::Opening);
+#endif
       break;
    }
 }
@@ -1483,33 +1509,52 @@ void k9Main::cbOutputChanged(int _index)
      case oISO:
 	Ui_MainDlg.wOutput->hide();
         Ui_MainDlg.urOutput->show();
-	Ui_MainDlg.urOutput->setMode( KFile::File);
-	Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
+#ifdef BACKLITE
+        Ui_MainDlg.urOutput->setMode(KUrlRequester::SAVE);
+        Ui_MainDlg.urOutput->setFilter("Iso Image (*.iso)");
+#else
+        Ui_MainDlg.urOutput->setMode( KFile::File);
+        Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
         Ui_MainDlg.urOutput->setFilter("*.iso|Iso Image (*.iso)");
+#endif
         Ui_MainDlg.urOutput->setUrl(KUrl(QDir::cleanPath(config.getPrefOutputIso()+"/"+title+".iso") ));
       break;
      case oFolder:
      case oAudio:
 	Ui_MainDlg.wOutput->hide();
         Ui_MainDlg.urOutput->show();
-	Ui_MainDlg.urOutput->setMode( KFile::Directory);
-	Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
+#ifdef BACKLITE
+        Ui_MainDlg.urOutput->setMode( KUrlRequester::DIRECTORY);
+#else
+        Ui_MainDlg.urOutput->setMode( KFile::Directory);
+        Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
+#endif
 	Ui_MainDlg.urOutput->setUrl(KUrl(QDir::cleanPath(_index==oAudio?config.getPrefOutputAudio():config.getPrefOutput())));
       break;
      case oMP4:
 	Ui_MainDlg.wOutput->hide();
         Ui_MainDlg.urOutput->show();
-	Ui_MainDlg.urOutput->setFilter("*.avi|Audio Video Interleave (*.avi)\n*.mpg|MPEG-1 and MPEG-2 systems (*.mpg)\n*.mp4|MPEG-4 format (*.mp4)\n*.asf|Advanced Streaming Format (*.asf)\n*.swf|Adobe Flash (*.swf)\n*.flv|Adobe Flash video files (*.flv)\n*.rm|RealVideo (*.rm)\n*.mov|QuickTime (*.mov)\n*.mkv|Matroska (*.mkv)");
-	Ui_MainDlg.urOutput->setMode(KFile::File) ;
-	Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
+#ifdef BACKLITE
+        Ui_MainDlg.urOutput->setFilter("Audio Video Interleave (*.avi);;MPEG-1 and MPEG-2 systems (*.mpg);;MPEG-4 format (*.mp4);;Advanced Streaming Format (*.asf);;Adobe Flash (*.swf);;Adobe Flash video files (*.flv);;RealVideo (*.rm);;QuickTime (*.mov);;Matroska (*.mkv)");
+        Ui_MainDlg.urOutput->setMode(KUrlRequester::SAVE) ;
+#else
+        Ui_MainDlg.urOutput->setFilter("*.avi|Audio Video Interleave (*.avi)\n*.mpg|MPEG-1 and MPEG-2 systems (*.mpg)\n*.mp4|MPEG-4 format (*.mp4)\n*.asf|Advanced Streaming Format (*.asf)\n*.swf|Adobe Flash (*.swf)\n*.flv|Adobe Flash video files (*.flv)\n*.rm|RealVideo (*.rm)\n*.mov|QuickTime (*.mov)\n*.mkv|Matroska (*.mkv)");
+        Ui_MainDlg.urOutput->setMode(KFile::File) ;
+        Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
+#endif
 	Ui_MainDlg.urOutput->setUrl(KUrl(QDir::cleanPath(config.getPrefOutputMpeg4()+"/"+title+".avi") ));
 	break;
      case oMPEG2:
 	Ui_MainDlg.wOutput->hide();
         Ui_MainDlg.urOutput->show();
-	Ui_MainDlg.urOutput->setFilter("*.mpg|MPEG-1 and MPEG-2 systems (*.mpg)");
-	Ui_MainDlg.urOutput->setMode(KFile::File) ;
-	Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
+#ifdef BACKLITE
+        Ui_MainDlg.urOutput->setFilter("MPEG-1 and MPEG-2 systems (*.mpg)");
+        Ui_MainDlg.urOutput->setMode(KUrlRequester::SAVE) ;
+#else
+        Ui_MainDlg.urOutput->setFilter("*.mpg|MPEG-1 and MPEG-2 systems (*.mpg)");
+        Ui_MainDlg.urOutput->setMode(KFile::File) ;
+        Ui_MainDlg.urOutput->fileDialog()->setOperationMode(KFileDialog::Saving);
+#endif
 	Ui_MainDlg.urOutput->setUrl(KUrl(QDir::cleanPath(config.getPrefOutputMpeg2()+"/"+title+".mpg") ));
       break;
 
