@@ -11,8 +11,8 @@
 //
 #include "k9updatefactor.h"
 
-k9UpdateFactor::k9UpdateFactor(QObject *parent, const char *name)
- : QThread()
+k9UpdateFactor::k9UpdateFactor(QObject *parent, const char *)
+ : QThread(parent)
 {
 }
 
