@@ -23,11 +23,14 @@
 #include <sys/stat.h>
 #include <fcntl.h>
 #include "dvdread.h"
+
+
 #ifdef BACKLITE
 #else
 #include <KStandardDirs>
 #include <KMessageBox>
 #include <KLocale>
+#include "k9config.h"
 #endif
 #include <QApplication>
 #include "k9dvdbackupinterface.h"
@@ -350,14 +353,18 @@ void k9play::play() {
     }
 
     /* set the language */
-    if (dvdnav_menu_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK ||
-            dvdnav_audio_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK ||
-            dvdnav_spu_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK) {
-        writeOutput( QString("ERR:Error on setting languages: %1\n").arg(dvdnav_err_to_string(dvdnav)));
-        emit sigError(i18n("Error on setting languages: %1").arg(dvdnav_err_to_string(dvdnav)));
-        return ;
+    k9Config config;
+    if (dvdnav_menu_language_select(dvdnav, config.getPrefAudioLang().toAscii().data()) != DVDNAV_STATUS_OK ||
+            dvdnav_audio_language_select(dvdnav, config.getPrefAudioLang().toAscii().data()) != DVDNAV_STATUS_OK ||
+            dvdnav_spu_language_select(dvdnav, config.getPrefSubtitleLang().toAscii().data()) != DVDNAV_STATUS_OK) {
+        if (dvdnav_menu_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK ||
+                dvdnav_audio_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK ||
+                dvdnav_spu_language_select(dvdnav, DVD_LANGUAGE) != DVDNAV_STATUS_OK) {
+            writeOutput( QString("ERR:Error on setting languages: %1\n").arg(dvdnav_err_to_string(dvdnav)));
+            emit sigError(i18n("Error on setting languages: %1").arg(dvdnav_err_to_string(dvdnav)));
+            return ;
+        }
     }
-
     /* set the PGC positioning flag to have position information relatively to the
      * whole feature instead of just relatively to the current chapter */
     if (dvdnav_set_PGC_positioning_flag(dvdnav, 1) != DVDNAV_STATUS_OK) {
